@@ -3,7 +3,7 @@
 ##############################################################
 ## Integrated AUC
 ##############################################################
-# AUC	- vector of AUC´s
+# AUC	- vector of AUC's
 # times	- vector of times
 # S		- vector of survival probability
 # tmax	- maximum timepoint
@@ -22,7 +22,7 @@ IntAUC <- function( AUC, times, S, tmax, auc.type="cumulative")
 		stop("auc.type must be one of 'cumulative' or 'incident'")
 	maxI <- sum( times <= tmax )
 	ind_S <- S[min(maxI+1,length(S))]
-	iAUC <- .C("int_auc",0.0,
+	iAUC <- .C("C_int_auc",0.0,
 			   as.numeric(AUC),
 			   as.numeric(times),
 			   as.numeric(S),
@@ -30,8 +30,9 @@ IntAUC <- function( AUC, times, S, tmax, auc.type="cumulative")
 			   as.integer(n_S),
 			   as.integer(maxI),
 			   as.numeric(ind_S),
-			   as.integer(auc.type-1),
-			   PACKAGE="survAUC")
+			   as.integer(auc.type-1))
+	#No longer needed since the symbol is registered in the NAMESPACE
+	#          ,PACKAGE="survAUC")
 	iAUC[[1]]
 }
 
