@@ -7,6 +7,6 @@
  *
  */
 
-SEXP Cham_Diao(SEXP LP, SEXP TH_TIME, SEXP TIME, SEXP EVENT, SEXP N_TIME, 
+SEXP C_Cham_Diao(SEXP LP, SEXP TH_TIME, SEXP TIME, SEXP EVENT, SEXP N_TIME, 
 			   SEXP TIME_NEW, SEXP EVENT_NEW, SEXP N_TIME_NEW, 
 			   SEXP N_LP, SEXP LPNEW, SEXP N_LPNEW);
