@@ -8,14 +8,14 @@
  */
 
 
-void spez_uno( double *spez, double *thres, double *t, double *marker, double *new_data, 
+void C_spec_uno( double *spez, double *thres, double *t, double *marker, double *new_data, 
 			  int *n_th, int *n_t, int *n_new_data );
-void sens_uno( double *sens, double *surv_time, double *status, double *thres, double *t, 
+void C_sens_uno( double *sens, double *surv_time, double *status, double *thres, double *t, 
 			  double *marker, double *new_surv, double *new_event, int *n_th, int *n_t, 
 			  int *n_new_data, int *n_surv );
-void auc_uno( double *auc, double *i_auc, double *sens, double *spec, double *surv_time,
+void C_auc_uno( double *auc, double *i_auc, double *sens, double *spec, double *surv_time,
 			 double *status, double *thres, double *t, double *marker, double *new_surv_t,
 			 double *new_event, int *n_th, int *n_t, int *n_new_data, int *n_surv);
-void Int_AUC( double *i_auc, double *auc, double *time, double *S, 
+void C_int_auc( double *i_auc, double *auc, double *time, double *S, 
 			 double *tmax, int *n_S, int *wChoice, int *maxI, double *maxS, int *Con_Inc);
 
